==> appstream-0.12.6-1-armv7h.pkg.tar.xz: usr/include/appstream/appstream.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2012-2015 Matthias Klumpp <matthias@tenstral.net>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the license, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __APPSTREAM_H
#define __APPSTREAM_H

#define __APPSTREAM_H_INSIDE__
#ifdef __cplusplus
extern "C" {
#endif

#include <as-component.h>
#include <as-enums.h>
#include <as-provided.h>
#include <as-metadata.h>
#include <as-pool.h>
#include <as-category.h>
#include <as-distro-details.h>
#include <as-icon.h>
#include <as-screenshot.h>
#include <as-image.h>
#include <as-bundle.h>
#include <as-release.h>
#include <as-artifact.h>
#include <as-checksum.h>
#include <as-translation.h>
#include <as-suggested.h>
#include <as-content-rating.h>
#include <as-launchable.h>
#include <as-relation.h>

#include <as-validator.h>
#include <as-validator-issue.h>

#include <as-utils.h>
#include <as-spdx.h>

#ifdef __cplusplus
};
#endif
#undef __APPSTREAM_H_INSIDE__

#endif /* __APPSTREAM_H */

==> appstream-1.0.1-2-armv7h.pkg.tar.xz: usr/include/appstream/appstream.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
 *
 * Copyright (C) 2012-2023 Matthias Klumpp <matthias@tenstral.net>
 *
 * Licensed under the GNU Lesser General Public License Version 2.1
 *
 * This library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the license, or
 * (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this library.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __APPSTREAM_H
#define __APPSTREAM_H

#define __APPSTREAM_H_INSIDE__

#include <as-version.h>
#include <as-macros.h>
#include <as-context.h>
#include <as-component.h>
#include <as-enum-types.h>
#include <as-provided.h>
#include <as-metadata.h>
#include <as-pool.h>
#include <as-category.h>
#include <as-developer.h>
#include <as-icon.h>
#include <as-screenshot.h>
#include <as-image.h>
#include <as-video.h>
#include <as-branding.h>
#include <as-bundle.h>
#include <as-release.h>
#include <as-release-list.h>
#include <as-artifact.h>
#include <as-checksum.h>
#include <as-translation.h>
#include <as-suggested.h>
#include <as-content-rating.h>
#include <as-agreement.h>
#include <as-agreement-section.h>
#include <as-launchable.h>
#include <as-relation.h>
#include <as-relation-check-result.h>
#include <as-issue.h>
#include <as-review.h>
#include <as-component-box.h>

#include <as-validator.h>
#include <as-validator-issue.h>

#include <as-utils.h>
#include <as-vercmp.h>
#include <as-spdx.h>
#include <as-system-info.h>

/* Helpers for languages using GIR */
#include <as-category-gi.h>

#undef __APPSTREAM_H_INSIDE__

#endif /* __APPSTREAM_H */
